BroadcastEventInterface<T> class abstract

BroadcastEventInterface 广播事件接口

Implementers

Constructors

BroadcastEventInterface({String? name})

Properties

count int
监听者数量
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void callback(T? data)) BroadcastSubscription?
emit(T? data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited