Injex class

Injex 依赖注入管理类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

debug([bool enable = true]) → void
delete<D>({String? tag, bool keepFactory = false}) → void
get<D>({String? tag, D factory()?}) → D?
put<D>(D object, {String? tag, bool keepAlive = false}) → void
PUBLIC APIS
putLater<D>(D factory(), {String? tag}) → void
remove<D>({String? tag, D? target, bool keepFactory = false}) → void