NavigationPageController<T> class

NavigationPageController a page controller used to manage data of the page and receive events like onInit and onFocused etc...

Implementers

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
mounted bool
getter/setter pair
params ↔ T?
params The params of the page. passed from previous page.
getter/setter pair
routeId String
routeId The id of the route which this controller belongs to.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title The title of the page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBeforeInit() Future<void>
onBeforeInitialized This method will be called when navigating to this page. Typically used to preload data. Inside delegate,the controller will be instantiated and call this method immediately. ! Attension: dont'do any expensive operation in this method to avoid frame drops.
onDispose() Future<void>
onDispose This method will be called when this page is disposed.
onFocused(bool focused) Future<void>
onFocused This method will be called when this page is focused or not.
onInit() Future<void>
onInitialize This method will be called when this page is initialized. called at State.initState
onWillDispose() Future<void>
onWillDispose This method will be called when this page is going to be disposed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited