onBeforeInit method

Future<void> onBeforeInit()

onBeforeInitialized This method will be called when navigating to this page. Typically used to preload data. Inside delegate,the controller will be instantiated and call this method immediately. ! Attension: dont'do any expensive operation in this method to avoid frame drops.

Implementation

Future<void> onBeforeInit() async {}