onInit method
onInitialize
This method will be called when this page is initialized. called at State.initState
Implementation
Future<void> onInit() async {
mounted = true;
}
onInitialize
This method will be called when this page is initialized. called at State.initState
Future<void> onInit() async {
mounted = true;
}