NavigationPageDescriptor class

NavigationPageDescriptor a navigation page descriptor name the named name of the page,multiple pages in stack can have the same name but different keys builder the builder of the page,return a widget which will be pushed to the stack in stack router,the widget will be wrapped with MaterialPage | CupertinoPage or custom page widget(inherit from Page). descides by StackRouterDelegateConfiguration.pageType controllerBuilder the builder of the page controller title the title of the page,name will be used if title is null

Implementers

Constructors

Properties

builder Widget Function(Key key)
final
controller NavigationPageController? Function()?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited