CustomTransitionPage<T> class

Inheritance

Constructors

CustomTransitionPage({required Widget child, required Widget transitionBuilder(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child), bool maintainState = true, bool fullscreenDialog = false, bool opaque = true, bool barrierDismissible = false, Color? barrierColor, String? barrierLabel, Duration transitionDuration = const Duration(milliseconds: 260), LocalKey? key, String? name, Object? arguments, String? restorationId})
const

Properties

arguments Object?
The arguments passed to this route.
finalinherited
barrierColor Color?
final
barrierDismissible bool
final
barrierLabel String?
final
canPop bool
When false, blocks the associated route from being popped.
finalinherited
child Widget
final
fullscreenDialog bool
final
hashCode int
The hash code for this object.
no setterinherited
key LocalKey?
The key associated with this page.
finalinherited
maintainState bool
final
name String?
The name of the route (e.g., "/settings").
finalinherited
onPopInvoked PopInvokedWithResultCallback<T>
Called after a pop on the associated route was handled.
finalinherited
opaque bool
final
restorationId String?
Restoration ID to save and restore the state of the Route configured by this page.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionBuilder Widget Function(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child)
final
transitionDuration Duration
final

Methods

canUpdate(Page other) bool
Whether this page can be updated with the other page.
inherited
createRoute(BuildContext context) Route<T>
Creates the Route that corresponds to this page.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited