GBOnStackRouteIsInitial class

GBOnStackRouteIsInitial Routes popped until initial route

Inheritance

Constructors

GBOnStackRouteIsInitial({bool? data})

Properties

data bool?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited