navigation/stack_router library

Classes

StackPageController<P>
StackPageController
StackPageDescriptor
StackRouterPage
StackPageState<W extends StatefulWidget, C extends StackPageController>
StackPageState Once page pushed and navigator rebuilt、 the state will be initialized. Get the built page through StackPageState.page and call its StackPageController.onInitialize
StackRoute
StackRoute Referrence to the page which had been built and exsists in route stack
StackRouteInformationParser
StackRouteInformationParser handle route information
StackRouteInformationProvider
StackRouteInformationProvider
StackRouteNavigationResult<T>
StackRoutePoppedUnexpectedlyException
StackRouterDelegate
StackRouterDelegate router delegate
StackRouterDelegateConfiguration
StackRouterDelegateConfiguration delegate configuration used to config initial route , custom toast & loading and so on