StackPageController<P> class

Inheritance

Constructors

StackPageController()

Properties

hashCode int
The hash code for this object.
no setterinherited
mounted bool
getter/setter pairinherited
params ↔ P?
params The params of the page. passed from previous page.
getter/setter pairinherited
routeId String
routeId The id of the route which this controller belongs to.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title The title of the page.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBeforeInit() Future<void>
onBeforeInitialized This method will be called when navigating to this page. Typically used to preload data. Inside delegate,the controller will be instantiated and call this method immediately. ! Attension: dont'do any expensive operation in this method to avoid frame drops.
inherited
onDispose() Future<void>
onDispose This method will be called when this page is disposed.
inherited
onFocused(bool focused) Future<void>
onFocused This method will be called when this page is focused or not.
inherited
onInit() Future<void>
onInitialize This method will be called when this page is initialized. called at State.initState
inherited
onWillDispose() Future<void>
onWillDispose This method will be called when this page is going to be disposed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited