StackRoute class

StackRoute Referrence to the page which had been built and exsists in route stack

Constructors

StackRoute({required String id, required Page page, required String name, Completer? completer, dynamic params, NavigationPageController? controller})

Properties

completer Completer?
getter/setter pair
controller NavigationPageController?
final
forResult bool
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
page Page
final
params ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited