StackRouterDelegate class

StackRouterDelegate router delegate

Inheritance
Mixed-in types

Properties

currentConfiguration Uri?
Called by the Router when it detects a route information may have changed as a result of rebuild.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
The key used for retrieving the current navigator.
no setteroverride
routes List<StackRoute>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
back({String? name, dynamic result, int step = 1, bool toInitial = false}) → dynamic
backToInitial({dynamic result}) → dynamic
build(BuildContext context) Widget
Called by the Router to obtain the widget tree that represents the current state.
override
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
go<T>(String name, {dynamic params, bool forResult = false}) Future<StackRouteNavigationResult?>
route manage apis go
handlePopRoute() Future<bool>
insert(OverlayEntry entry, {OverlayEntry? above, OverlayEntry? below}) → dynamic
Overlay Part
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
popRoute() Future<bool>
Called by the Router when the Router.backButtonDispatcher reports that the operating system is requesting that the current route be popped.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setInitialRoutePath(Uri configuration) Future<void>
Called by the Router at startup with the structure that the RouteInformationParser obtained from parsing the initial route.
inherited
setNewRoutePath(Uri configuration) Future<Uri>
handle routes pushed by operating system, typically processing initial route
override
setRestoredRoutePath(Uri configuration) Future<void>
Called by the Router during state restoration.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) StackRouterDelegate
get current delegate through context