StackRouterDelegateConfiguration class
StackRouterDelegateConfiguration delegate configuration used to config initial route , custom toast & loading and so on
Constructors
- StackRouterDelegateConfiguration({String initialRoute = '/', Route? onUnknownRoute(RouteSettings)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialRoute → String
-
final
- onUnknownRoute → Route? Function(RouteSettings)?
-
unknown route handler
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited