ResponsiveRatioSize class

Constructors

ResponsiveRatioSize(Size actual, Size design)
ResponsiveRatioSize.zero()

Properties

actual Size
getter/setter pair
design Size
getter/setter pair
disabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

h(num n) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sh(num n) → dynamic
sw(num n) → dynamic
toString() String
A string representation of this object.
inherited
w(num n) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared ResponsiveRatioSize
no setter