ResponsiveRatioSizeProvider class

ResponsiveRatioSizeProvider

=== Major iPhone Screen Sizes Name Logical Size Physical Size iPhone 8 375 × 667 750 × 1334 iPhone 12/13/14 390 × 844 1170 × 2532 iPhone 16 393 × 852 1170 × 2556 iPhone 16 Plus 430 × 932 1290 × 2796 iPhone 16 Pro 402 × 874 1206 × 2622 iPhone 16 Pro Max 440 × 956 1320 × 2868

update: 2025-01-17

use 390 x 844 as default design size

Inheritance

Constructors

ResponsiveRatioSizeProvider({Key? key, Size design = defaultDesignSize, bool usePortraitInitialLayout = false, bool disabled = false, required Widget child})
const

Properties

child Widget
final
design Size
design size of app default: 390 x 844
final
disabled bool
don't provide responsive size
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usePortraitInitialLayout bool
traited device's orientation as Portrait when initialize
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ResponsiveRatioSizeProvider>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultDesignSize → const Size