thunderingcat_core library

Classes

BackHandlerEventSubscription
Broadcast
BroadcastEvent<T>
BroadcastEvent 实例化广播事件、用于非全局范围内,可销毁场景中使用 例如: 仅在当前页面内有效。
BroadcastEventInterface<T>
BroadcastEventInterface 广播事件接口
BroadcastListener
Broadcast 广播类及相关类型定义
BroadcastSubscription
CustomTransitionPage<T>
CustomTransitionPageRoute<T>
GBOnStackRouteIsInitial
GBOnStackRouteIsInitial Routes popped until initial route
GBOnStackRouteWillChange
GBOnStackRouteWillChange Routes' gonna change
GBOnStackRouteWillChangeData
GlobalBroadcastEventInterface<T>
GlobalBroadcastEventInterface 全局广播事件接口 全局广播、应用生命周期内有效
Injex
Injex 依赖注入管理类
LazyBuildableTabRoute
StackPageController<P>
StackPageController
StackPageDescriptor
StackRouterPage
StackPageState<W extends StatefulWidget, C extends StackPageController>
StackPageState Once page pushed and navigator rebuilt、 the state will be initialized. Get the built page through StackPageState.page and call its StackPageController.onInitialize
StackRoute
StackRoute Referrence to the page which had been built and exsists in route stack
StackRouteInformationParser
StackRouteInformationParser handle route information
StackRouteInformationProvider
StackRouteInformationProvider
StackRouteNavigationResult<T>
StackRoutePoppedUnexpectedlyException
StackRouterBackButtonDispatcher
StackRouterBackHandler
StackRouterDelegate
StackRouterDelegate router delegate
StackRouterDelegateConfiguration
StackRouterDelegateConfiguration delegate configuration used to config initial route , custom toast & loading and so on
TabPageController
TabPageDescriptor
TabPageRoute
TabPageRoute Referrence to the page which had been built and exsists in route stack
TabRouter
TabRouter manage tab pages
TabRouterState
Unique

Enums

StackPageType
StackRouteChangeType
Global Navigation Events