Broadcast class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
addEventListener<
E> (void listener(E event), {String? name}) → BroadcastSubscription - used to listen events inherited from GlobalBroadcastEventInterface
-
addListener<
T> (dynamic event, void listener(T data), {bool single = false}) → BroadcastSubscription -
count<
E> ([String? event]) → int -
emit<
E> ({String? name, dynamic data}) → void -
removeAllListeners<
E> ([String? event]) → void