navigation/base library
Classes
- NavigationPageController a page controller used to manage data of the page and receive events like onInit and onFocused etc...
-
NavigationPageDescriptor
a navigation page descriptor
name the named name of the page,multiple pages in stack can have the same name but different keys
builder the builder of the page,return a widget which will be pushed to the stack
in stack router,the widget will be wrapped with MaterialPage | CupertinoPage
or custom page widget(inherit from Page). descides by
StackRouterDelegateConfiguration.pageTypecontrollerBuilderthe builder of the page controller title the title of the page,name will be used if title is null