GBOnStackRouteWillChangeData class
Constructors
- GBOnStackRouteWillChangeData({required String routeId, required String routeName, required String targetRouteId, required String targetRouteName, required StackRouteChangeType type, bool isInitialRoute = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialRoute → bool
-
final
- routeId → String
-
final
- routeName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetRouteId → String
-
final
- targetRouteName → String
-
final
- type → StackRouteChangeType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited