Navigation class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
back({String? name, dynamic result, int step = 1})
→ Future<void>
-
-
backToInitial({dynamic result, int? tabIndex, String? tabName})
→ Future<void>
-
-
go<T>(String name, {dynamic params, bool forResult = false})
→ Future<StackRouteNavigationResult?>
-
Stack Navigation Actions
-
goForResult<T>(String name, {dynamic params})
→ Future<StackRouteNavigationResult?>
-
-
insert(OverlayEntry entry, {OverlayEntry? above, OverlayEntry? below})
→ void
-
Overlay Actions
-
newRouterConfig({required List<StackPageDescriptor> pages, StackRouterDelegateConfiguration? config})
→ RouterConfig<Uri>
-
Navigation Constructors
-
newRouterConfigWithTabNavigator({required List<StackPageDescriptor> pages, required List<TabPageDescriptor> tabPages, required double tabHeight(BuildContext), required Widget tabBuilder(BuildContext, List<String>, int), bool lazy = false, int initialTab = 0, String initialRoute = '/'})
→ RouterConfig<Uri>
-
-
setNewTabIndex(int index)
→ Future<int?>
-
Tab Navigation Actions
-
setNewTabRoute(String tab, {String? routeId})
→ Future<int?>
-