StackPageDescriptor class

StackRouterPage

Inheritance

Constructors

StackPageDescriptor({required String name, required Widget builder(Key key), String? title, NavigationPageController? controller()?, StackPageType type = StackPageType.material})

Properties

builder → Widget Function(Key key)
finalinherited
controller → NavigationPageController? Function()?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
finalinherited
type → StackPageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited